Module: GitDump::Version::Base
- Included in:
- GitDump::Version, Builder
- Defined in:
- lib/git_dump/version/base.rb
Overview
Common methods in Version and Builder
Instance Method Summary collapse
-
#[](path) ⇒ Object
Retrive tree or entry at path, return nil if there is nothing at path.
-
#each(&block) ⇒ Object
Iterate over every tree/entry at root level.
-
#each_recursive(&block) ⇒ Object
Iterate over all entries recursively.
Instance Method Details
#[](path) ⇒ Object
Retrive tree or entry at path, return nil if there is nothing at path
6 7 8 |
# File 'lib/git_dump/version/base.rb', line 6 def [](path) tree[path] end |
#each(&block) ⇒ Object
Iterate over every tree/entry at root level
11 12 13 |
# File 'lib/git_dump/version/base.rb', line 11 def each(&block) tree.each(&block) end |
#each_recursive(&block) ⇒ Object
Iterate over all entries recursively
16 17 18 |
# File 'lib/git_dump/version/base.rb', line 16 def each_recursive(&block) tree.each_recursive(&block) end |